@@ -1,5 +1,3 @@
-requireNamespace("stringr", quietly = T)
-
 ###########################################################################
 # create table / index definitions for DBI that are used at query time
 
@@ -185,9 +183,7 @@ check_levelAttributeName<-function(emuDBhandle,name){
 #################################
 # actual query functions
 
-## @param emuDBhandle
-## @param levelName
-## @param intermResTablePrefix "left" or "right" 
+#################################
 query_labels <- function(emuDBhandle, levelName, intermResTableSuffix, conditionText, useSubsets, filteredTablesSuffix){
   
   if(useSubsets){
@@ -258,9 +254,9 @@ query_labels <- function(emuDBhandle, levelName, intermResTableSuffix, condition
                                                  "VALUES ('", levelName, "')"))
 }
 
-
-query_databaseEqlFUNCQ<-function(emuDBhandle, q, intermResTableSuffix, useSubsets, filteredTablesSuffix){
-  # BNF: FUNCQ = POSQ | NUMQ;
+##############################
+query_databaseEqlFUNCQ <- function(emuDBhandle, q, intermResTableSuffix, useSubsets, filteredTablesSuffix, verbose){
+  # EBNF: FUNCQ = POSQ | NUMQ;
   qTrim=stringr::str_trim(q)
   if(useSubsets){
     itemsTableName = "items_filtered_subset_tmp"
@@ -315,7 +311,7 @@ query_databaseEqlFUNCQ<-function(emuDBhandle, q, intermResTableSuffix, useSubset
       
       
       funcName=stringr::str_trim(substr(qTrim,1,prbOpen-1))
-      # BNF: POSA = POSFKT,'(',EBENE,',',EBENE,')','=','0'| '1';
+      # EBNF: POSQ = POSFCT,'(',Level,',',Level,')','=','0'| '1';
       itemsAsSeqs=NULL
       
       level1=get_levelNameForAttributeName(emuDBhandle, param1)
@@ -339,7 +335,7 @@ query_databaseEqlFUNCQ<-function(emuDBhandle, q, intermResTableSuffix, useSubset
       
       
       query_databaseHier(emuDBhandle, firstLevelName = level1, secondLevelName = level2, 
-                         leftTableSuffix = level1ItemsTableSuffix, rightTableSuffix = level2ItemsTableSuffix, filteredTablesSuffix = filteredTablesSuffix) # result written to lr_exp_res_tmp table
+                         leftTableSuffix = level1ItemsTableSuffix, rightTableSuffix = level2ItemsTableSuffix, filteredTablesSuffix = filteredTablesSuffix, verbose = verbose) # result written to lr_exp_res_tmp table
       
       
       # create temp table to insert 
@@ -375,7 +371,7 @@ query_databaseEqlFUNCQ<-function(emuDBhandle, q, intermResTableSuffix, useSubset
                                                      ""))
       
       
-      # BNF: VOP = '=' | '!=' | '>' | '<' | '<=' | '>=';
+      # EBNF: COP = '=' | '!=' | '>' | '<' | '<=' | '>=';
       if(funcName=='Start' | funcName=='End' | funcName=='Medial'){
         
         if(funcValueTerm!=''){
@@ -490,7 +486,7 @@ query_databaseEqlFUNCQ<-function(emuDBhandle, q, intermResTableSuffix, useSubset
           sqlFuncOpr=funcOpr
         }
         
-        # BNF: NUMA = 'Num','(',EBENE,',',EBENE,')',VOP,INTPN;
+        # EBNF: NUMQ = 'Num','(',Level,',',Level,')',COP,INTPN;
         # NOTE: return value level is param1 here
         DBI::dbGetQuery(emuDBhandle$connection, paste0("INSERT INTO items_as_seqs_tmp ",
                                                        "SELECT sit.db_uuid, sit.session, sit.bundle, i1.item_id AS seq_start_id, i1.item_id AS seq_end_id, 1 AS seq_len, '", param1, "' AS level ",
@@ -526,33 +522,9 @@ query_databaseEqlFUNCQ<-function(emuDBhandle, q, intermResTableSuffix, useSubset
   }
 }
 
-query_databaseEqlSQ <- function(emuDBhandle, q, intermResTableSuffix, useSubsets, filteredTablesSuffix){
-  # BNF: SQ = LABELQ | FUNCQ;
-  qTrim=stringr::str_trim(q)
-  res=NULL
-  # detect function calls by existence of round brackets
-  prbOpen=get_stringPosition(string=qTrim,searchStr='(',literalQuote="'")
-  if(prbOpen!=-1){
-    prbClose=get_stringPosition(string=qTrim,searchStr=')',literalQuote="'")
-    if(prbClose==-1){
-      stop("Syntax error: Missing closing round bracket ')' in '",q,"'\n")
-    }else{
-      if(prbOpen>prbClose){
-        stop("Syntax error: Expected opening round bracket '(' before closing round bracket in '",q,"'\n")
-      }
-      if(prbOpen==1){
-        stop("Syntax error: Expected function name in '",q,"'\n")
-      }
-      query_databaseEqlFUNCQ(emuDBhandle, qTrim, intermResTableSuffix, useSubsets, filteredTablesSuffix)
-    }
-  }else{
-    # No round brackets, assuming a level query
-    query_databaseEqlLABELQ(emuDBhandle, qTrim, useSubsets, intermResTableSuffix = intermResTableSuffix, filteredTablesSuffix)
-  }
-}
-
+###########################
 query_databaseEqlLABELQ <- function(emuDBhandle, q, useSubsets, intermResTableSuffix, filteredTablesSuffix){
-  # BNF: ETIKETTA = ['#'],EBENE,('=' | '!='),ETIKETTALTERNATIVEN;
+  # EBNF: LABELQ = ['#'],LEVEL,("=" | "==" | "!=" | "=~" | "!~"),LABELALTERNATIVES;
   
   qTrim=stringr::str_trim(q)
   dbConfig = load_DBconfig(emuDBhandle)
@@ -566,7 +538,7 @@ query_databaseEqlLABELQ <- function(emuDBhandle, q, useSubsets, intermResTableSu
       lvlName=lvlTrim
       if(grepl('^#',lvlTrim)){
         # projection marker
-        # the BNF does not allow white space between '#' and level string
+        # the EBNF does not allow white space between '#' and level string
         # but the implementation of Emu does, so we allow it here too
         
         lvlName=stringr::str_trim(substring(lvlTrim,2))
@@ -590,7 +562,7 @@ query_databaseEqlLABELQ <- function(emuDBhandle, q, useSubsets, intermResTableSu
         }
       }
       
-      # BNF: ETIKETTALTERNATIVEN = ETIKETT , {'|',ETIKETT};
+      # EBNF: LABELALTERNATIVES = LABEL , {'|',LABEL};
       # parse alternatives
       labelAlts=c()
       lp=1
@@ -614,11 +586,11 @@ query_databaseEqlLABELQ <- function(emuDBhandle, q, useSubsets, intermResTableSu
       
       labelAltsUq=c()
       # unquote labels
-      # BNF: ETIKETT = ETIKETTIERUNG | ("'",ETIKETTIERUNG,"'");
+      # EBNF: LABEL = LABELING | ("'",LABELING,"'");
       # Suggestion for improvement:
       # labelGroups (legacy EMU 'legal' directive) MUST NOT be quoted, to distinguish labelGroups from ordinary label or label pattern:
-      # BNF__:ETIKETT = LABEL_GROUP_NAME | ETIKETTIERUNG | ("'",ETIKETTIERUNG,"'");
-      #        ETIKETTIERUNG = {ALPHA|DIGIT}
+      # EBNF: LABEL = LABEL_GROUP_NAME | LABELING | ("'",LABELING,"'");
+      #        LABELING = {ALPHA|DIGIT}
       
       for(labelAlt in labelAlts){
         label=NULL
@@ -686,8 +658,33 @@ query_databaseEqlLABELQ <- function(emuDBhandle, q, useSubsets, intermResTableSu
   stop("Syntax error: No operator found.")
 }
 
-query_databaseEqlCONJQ<-function(emuDBhandle, q, intermResTableSuffix, filteredTablesSuffix){
-  # BNF: CONJQ = SQ,{'&',SQ};
+query_databaseEqlSQ <- function(emuDBhandle, q, intermResTableSuffix, useSubsets, filteredTablesSuffix, verbose){
+  # EBNF: SQ = LABELQ | FUNCQ;
+  qTrim=stringr::str_trim(q)
+  res=NULL
+  # detect function calls by existence of round brackets
+  prbOpen=get_stringPosition(string=qTrim,searchStr='(',literalQuote="'")
+  if(prbOpen!=-1){
+    prbClose=get_stringPosition(string=qTrim,searchStr=')',literalQuote="'")
+    if(prbClose==-1){
+      stop("Syntax error: Missing closing round bracket ')' in '",q,"'\n")
+    }else{
+      if(prbOpen>prbClose){
+        stop("Syntax error: Expected opening round bracket '(' before closing round bracket in '",q,"'\n")
+      }
+      if(prbOpen==1){
+        stop("Syntax error: Expected function name in '",q,"'\n")
+      }
+      query_databaseEqlFUNCQ(emuDBhandle, qTrim, intermResTableSuffix, useSubsets, filteredTablesSuffix, verbose = verbose)
+    }
+  }else{
+    # No round brackets, assuming a level query
+    query_databaseEqlLABELQ(emuDBhandle, qTrim, useSubsets, intermResTableSuffix = intermResTableSuffix, filteredTablesSuffix)
+  }
+}
+
+query_databaseEqlCONJQ<-function(emuDBhandle, q, intermResTableSuffix, filteredTablesSuffix, verbose){
+  # EBNF: CONJQ = SQ,{'&',SQ};
   qTrim=stringr::str_trim(q)
   conditions=list()
   # initialize with empty result
@@ -719,7 +716,7 @@ query_databaseEqlCONJQ<-function(emuDBhandle, q, intermResTableSuffix, filteredT
       }
     }
     # execute query on term
-    query_databaseEqlSQ(emuDBhandle, condStr, intermResTableSuffix, useSubsets = useSubsets, filteredTablesSuffix)
+    query_databaseEqlSQ(emuDBhandle, condStr, intermResTableSuffix, useSubsets = useSubsets, filteredTablesSuffix, verbose = verbose)
     # set resultLevel of first term
     if(is.null(resultLevel)){
       termResLevel = DBI::dbGetQuery(emuDBhandle$connection, paste0("SELECT * FROM interm_res_meta_infos_tmp_", intermResTableSuffix))$result_level
@@ -785,8 +782,8 @@ reduce_hierTrapezeIntermRes_minMaxSeqIdx <- function(emuDBhandle){
   
 }
 
-
-query_databaseHier <- function(emuDBhandle, firstLevelName, secondLevelName, leftTableSuffix, rightTableSuffix, filteredTablesSuffix, minMaxSeqIdxLeafOnly = F) {
+##########################
+query_databaseHier <- function(emuDBhandle, firstLevelName, secondLevelName, leftTableSuffix, rightTableSuffix, filteredTablesSuffix, minMaxSeqIdxLeafOnly = F, verbose = F) {
   
   # create temp tables for hier query (should maybe be moved to external functions)
   hier_left_trapeze_interm_res_tmp = paste0("CREATE TEMP TABLE IF NOT EXISTS hier_left_trapeze_interm_res_tmp (",
@@ -844,6 +841,19 @@ query_databaseHier <- function(emuDBhandle, firstLevelName, secondLevelName, lef
   # get hierarchy paths
   connectHierPaths = get_hierPathsConnectingLevels(emuDBhandle, firstLevelName, secondLevelName)
   
+  if(verbose & length(connectHierPaths) >= 2){
+
+    cat(paste0("More than one path connecting: '", firstLevelName, "' and '", secondLevelName, "' was found! The paths were: \n" ))
+    for(i in 1:length(connectHierPaths)){
+      cat(paste0(i, ".) ", paste0(connectHierPaths[[i]], collapse = "->")), "\n")
+    }
+    idx <- readline(prompt="Choose a path by selecting its number (note that comma seperated numbers (e.g., 1, 2, 3) works to select multiple paths): ")
+
+    idx = as.integer(stringr::str_split(idx, ",\\s*", simplify = T))
+
+    connectHierPaths = connectHierPaths[idx]
+  }
+  
   # loop through multiple paths
   for(connectHierPath in connectHierPaths){
     
@@ -978,7 +988,7 @@ query_databaseHier <- function(emuDBhandle, firstLevelName, secondLevelName, lef
 
 
 ##################################
-query_databaseEqlInBracket<-function(emuDBhandle, q, intermResTableSuffix, leftRightTableNrCounter = 0, filteredTablesSuffix){
+query_databaseEqlInBracket<-function(emuDBhandle, q, intermResTableSuffix, leftRightTableNrCounter = 0, filteredTablesSuffix, verbose){
   parseRes=list()
   qTrim=stringr::str_trim(q)
   # parse SEQQ or DOMQ
@@ -1004,8 +1014,8 @@ query_databaseEqlInBracket<-function(emuDBhandle, q, intermResTableSuffix, leftR
     create_intermResTmpQueryTablesDBI(emuDBhandle, suffix = leftTableSuffix)
     create_intermResTmpQueryTablesDBI(emuDBhandle, suffix = rightTableSuffix)
     
-    query_databaseWithEql(emuDBhandle, left, intermResTableSuffix = leftTableSuffix, leftRightTableNrCounter, filteredTablesSuffix)
-    query_databaseWithEql(emuDBhandle, right, intermResTableSuffix = rightTableSuffix, leftRightTableNrCounter + 1, filteredTablesSuffix)
+    query_databaseWithEql(emuDBhandle, left, intermResTableSuffix = leftTableSuffix, leftRightTableNrCounter, filteredTablesSuffix, verbose)
+    query_databaseWithEql(emuDBhandle, right, intermResTableSuffix = rightTableSuffix, leftRightTableNrCounter + 1, filteredTablesSuffix, verbose)
     
     # check if left or right side results are empty -> clear tabels and return
     nLeftResIts = DBI::dbGetQuery(emuDBhandle$connection, paste0("SELECT COUNT(*) AS n FROM interm_res_items_tmp_", leftTableSuffix))$n
@@ -1055,7 +1065,7 @@ query_databaseEqlInBracket<-function(emuDBhandle, q, intermResTableSuffix, leftR
         return()
       }
       
-      query_databaseHier(emuDBhandle, lResLvl, rResLvl, leftTableSuffix, rightTableSuffix, filteredTablesSuffix) # result written to lr_exp_res_tmp
+      query_databaseHier(emuDBhandle, lResLvl, rResLvl, leftTableSuffix, rightTableSuffix, filteredTablesSuffix, verbose = verbose) # result written to lr_exp_res_tmp
       
       nLrExpRes = DBI::dbGetQuery(emuDBhandle$connection, "SELECT COUNT(*) AS n FROM lr_exp_res_tmp")$n
       if(nLrExpRes>0){
@@ -1068,11 +1078,6 @@ query_databaseEqlInBracket<-function(emuDBhandle, q, intermResTableSuffix, leftR
           DBI::dbGetQuery(emuDBhandle$connection, paste0("DELETE FROM interm_res_proj_items_tmp_", intermResTableSuffix))
           DBI::dbWriteTable(emuDBhandle$connection, paste0("interm_res_proj_items_tmp_", intermResTableSuffix), reducedPI, append = T, row.names = F)
           
-          # move meta infos to correct table
-          # allMeta = DBI::dbGetQuery(emuDBhandle$connection, paste0("SELECT * FROM interm_res_meta_infos_tmp_", leftTableSuffix))
-          # DBI::dbGetQuery(emuDBhandle$connection, paste0("DELETE FROM interm_res_meta_infos_tmp_", intermResTableSuffix))
-          # DBI::dbWriteTable(emuDBhandle$connection, paste0("interm_res_meta_infos_tmp_", intermResTableSuffix), allMeta, append = T)
-          
         }
         
         if(nRightProjItems != 0){
@@ -1084,20 +1089,13 @@ query_databaseEqlInBracket<-function(emuDBhandle, q, intermResTableSuffix, leftR
           DBI::dbGetQuery(emuDBhandle$connection, paste0("DELETE FROM interm_res_proj_items_tmp_", intermResTableSuffix))
           DBI::dbWriteTable(emuDBhandle$connection, paste0("interm_res_proj_items_tmp_", intermResTableSuffix), reducedPI, append = T, row.names = F)
           
-          # move meta infos to correct table
-          # allMeta = DBI::dbGetQuery(emuDBhandle$connection, paste0("SELECT * FROM interm_res_meta_infos_tmp_", rightTableSuffix))
-          # DBI::dbGetQuery(emuDBhandle$connection, paste0("DELETE FROM interm_res_meta_infos_tmp_", intermResTableSuffix))
-          # DBI::dbWriteTable(emuDBhandle$connection, paste0("interm_res_meta_infos_tmp_", intermResTableSuffix), allMeta, append = T)
-          
         }
       }
       
-      # if(nRightProjItems == 0 & nRightProjItems == 0){
       # if no projItems -> place left Meta infos in result table
       allMeta = DBI::dbGetQuery(emuDBhandle$connection, paste0("SELECT * FROM interm_res_meta_infos_tmp_", leftTableSuffix))
       DBI::dbGetQuery(emuDBhandle$connection, paste0("DELETE FROM interm_res_meta_infos_tmp_", intermResTableSuffix))
       DBI::dbWriteTable(emuDBhandle$connection, paste0("interm_res_meta_infos_tmp_", intermResTableSuffix), allMeta, append = T, row.names = F)
-      # }
       
       # place result in correct table
       resItems = DBI::dbGetQuery(emuDBhandle$connection, "SELECT DISTINCT db_uuid, session, bundle, l_seq_start_id AS seq_start_id, l_seq_end_id AS seq_end_id, l_seq_len AS seq_len, l_level AS level, l_seq_start_seq_idx AS seq_start_seq_idx, l_seq_end_seq_idx AS seq_end_seq_idx FROM lr_exp_res_tmp")
@@ -1184,62 +1182,17 @@ query_databaseEqlInBracket<-function(emuDBhandle, q, intermResTableSuffix, leftR
     }
     return()
   }else{
-    query_databaseWithEql(emuDBhandle, qTrim, intermResTableSuffix, leftRightTableNrCounter, filteredTablesSuffix)
+    query_databaseWithEql(emuDBhandle, qTrim, intermResTableSuffix, leftRightTableNrCounter, filteredTablesSuffix, verbose = verbose)
   }
 }
 
-## Query EMU database
-## 
-## @param database object of class emuDB
-## @param query EQL query string
-## @return EMU seglist
-## @export
-## @keywords emuDB database query Emu EQL 
-## 
-query_databaseWithEqlEmusegs<-function(emuDBhandle, query, timeRefSegmentLevel, filteredTablesSuffix, calcTimes){
-  # create "root" intermediate result tables
-  create_intermResTmpQueryTablesDBI(emuDBhandle, suffix = "root")
-  # query emuDB
-  query_databaseWithEql(emuDBhandle, query, intermResTableSuffix = "root", leftRightTableNrCounter = 0, filteredTablesSuffix)
-  # escape singel quotes
-  query = gsub("'", "''", query)
-  DBI::dbGetQuery(emuDBhandle$connection, paste0("UPDATE interm_res_meta_infos_tmp_root SET query_str = '", query, "'"))
-  emusegs=convert_queryResultToEmusegs(emuDBhandle, timeRefSegmentLevel, filteredTablesSuffix, calcTimes)
-  return(emusegs)
-  
-}
-
-####################
-query_databaseWithEqlEmuRsegs<-function(emuDBhandle, query, timeRefSegmentLevel, filteredTablesSuffix, calcTimes){
-  # create "root" intermediate result tables
-  create_intermResTmpQueryTablesDBI(emuDBhandle, suffix = "root")
-  # query emuDB
-  query_databaseWithEql(emuDBhandle, query, intermResTableSuffix = "root", leftRightTableNrCounter = 0, filteredTablesSuffix)
-  # escape singel quotes
-  queryStr = gsub("'", "''", query)
-  # DBI::dbGetQuery(emuDBhandle$connection, paste0("UPDATE interm_res_meta_infos_tmp_root SET query_str = '", queryStr, "'"))
-  emuRsegs = convert_queryResultToEmuRsegs(emuDBhandle, timeRefSegmentLevel, filteredTablesSuffix, queryStr = queryStr, calcTimes)
-  return(emuRsegs)
-  
-}
-
-
-
-
-## Query EMU database
-## 
-## @param database object of class emuDB
-## @param query EQL query string
-## @return result set object
-## @export
-## @keywords emuDB database query Emu EQL 
-## 
-query_databaseWithEql<-function(emuDBhandle, query, intermResTableSuffix, leftRightTableNrCounter, filteredTablesSuffix){
+###################
+query_databaseWithEql<-function(emuDBhandle, query, intermResTableSuffix, leftRightTableNrCounter, filteredTablesSuffix, verbose){
   parseRes=list()
   qTrim=stringr::str_trim(query)
   brOpenPos=get_charPosition(qTrim,'[',literalQuote="'")
   if(brOpenPos==-1){
-    query_databaseEqlCONJQ(emuDBhandle, qTrim, intermResTableSuffix = intermResTableSuffix, filteredTablesSuffix)
+    query_databaseEqlCONJQ(emuDBhandle, qTrim, intermResTableSuffix = intermResTableSuffix, filteredTablesSuffix, verbose)
     return()
   }else{
     
@@ -1258,13 +1211,42 @@ query_databaseWithEql<-function(emuDBhandle, query, intermResTableSuffix, leftRi
     
     #parse string in bracket
     inBr=substr(qTrim,brOpenPos+1,brClosePos-1)
-    query_databaseEqlInBracket(emuDBhandle, inBr, intermResTableSuffix, leftRightTableNrCounter, filteredTablesSuffix)
+    query_databaseEqlInBracket(emuDBhandle, inBr, intermResTableSuffix, leftRightTableNrCounter, filteredTablesSuffix, verbose = verbose)
     return()
     
   }
   stop("Unknown syntax error.")
 }
 
+####################
+query_databaseWithEqlEmusegs<-function(emuDBhandle, query, timeRefSegmentLevel, filteredTablesSuffix, calcTimes, verbose){
+  # create "root" intermediate result tables
+  create_intermResTmpQueryTablesDBI(emuDBhandle, suffix = "root")
+  # query emuDB
+  query_databaseWithEql(emuDBhandle, query, intermResTableSuffix = "root", leftRightTableNrCounter = 0, filteredTablesSuffix, verbose)
+  # escape singel quotes
+  query = gsub("'", "''", query)
+  DBI::dbGetQuery(emuDBhandle$connection, paste0("UPDATE interm_res_meta_infos_tmp_root SET query_str = '", query, "'"))
+  emusegs=convert_queryResultToEmusegs(emuDBhandle, timeRefSegmentLevel, filteredTablesSuffix, calcTimes, verbose)
+  return(emusegs)
+  
+}
+
+####################
+query_databaseWithEqlEmuRsegs<-function(emuDBhandle, query, timeRefSegmentLevel, filteredTablesSuffix, calcTimes, verbose){
+  # create "root" intermediate result tables
+  create_intermResTmpQueryTablesDBI(emuDBhandle, suffix = "root")
+  # query emuDB
+  query_databaseWithEql(emuDBhandle, query, intermResTableSuffix = "root", leftRightTableNrCounter = 0, filteredTablesSuffix, verbose = verbose)
+  # escape single quotes
+  queryStr = gsub("'", "''", query)
+  # DBI::dbGetQuery(emuDBhandle$connection, paste0("UPDATE interm_res_meta_infos_tmp_root SET query_str = '", queryStr, "'"))
+  emuRsegs = convert_queryResultToEmuRsegs(emuDBhandle, timeRefSegmentLevel, filteredTablesSuffix, queryStr = queryStr, calcTimes, verbose)
+  return(emuRsegs)
+  
+}
+
+
 ##' Query emuDB
 ##' @description Function to query an emuDB
 ##' @details Evaluates a query string of query language queryLang on an emuDB referenced by dbName and returns a segment list of desired type resultType.  
@@ -1283,6 +1265,7 @@ query_databaseWithEql<-function(emuDBhandle, query, intermResTableSuffix, leftRi
 ##' @param resultType type (class name) of result
 ##' @param calcTimes calculate times for resulting segments (results in \code{NA} values for start and end times in emuseg/emuRsegs). As it can be very computationally expensive to 
 ##' calculate the times for large nested hierarchies it can be turned of via this boolian parameter. 
+##' @param verbose be verbose. Set this to \code{TRUE} if you wish to choose which path to traverse on intersecting hierarchies. If set to \code{FALSE} (the default) all paths will be traversed (= legacy EMU bahaviour).
 ##' @return result set object of class resultType (default: \link{emuRsegs}, compatible to legacy type \link{emusegs})
 ##' @export
 ##' @seealso \code{\link{load_emuDB}}
@@ -1315,7 +1298,10 @@ query_databaseWithEql<-function(emuDBhandle, query, intermResTableSuffix, leftRi
 ##' 
 ##' }
 ##' 
-query <- function(emuDBhandle, query, sessionPattern = '.*', bundlePattern = '.*', queryLang = 'EQL2', timeRefSegmentLevel = NULL, resultType = NULL, calcTimes = T){
+query <- function(emuDBhandle, query, sessionPattern = '.*', bundlePattern = '.*', 
+                  queryLang = 'EQL2', timeRefSegmentLevel = NULL, resultType = NULL, 
+                  calcTimes = TRUE, verbose = FALSE){
+  
   if(queryLang=='EQL2'){
     # create temp tables 
     drop_allTmpTablesDBI(emuDBhandle)
@@ -1357,12 +1343,12 @@ query <- function(emuDBhandle, query, sessionPattern = '.*', bundlePattern = '.*
       filteredTablesSuffix = "_filtered_tmp"
     }
     if(is.null(resultType)){
-      emuRsegs = query_databaseWithEqlEmuRsegs(emuDBhandle,query,timeRefSegmentLevel, filteredTablesSuffix, calcTimes)
+      emuRsegs = query_databaseWithEqlEmuRsegs(emuDBhandle,query,timeRefSegmentLevel, filteredTablesSuffix, calcTimes, verbose = verbose)
       drop_allTmpTablesDBI(emuDBhandle)
       return(emuRsegs)
     }else{
       if(resultType=='emuRsegs'){
-        emuRsegs = query_databaseWithEqlEmuRsegs(emuDBhandle,query,timeRefSegmentLevel, filteredTablesSuffix, calcTimes)
+        emuRsegs = query_databaseWithEqlEmuRsegs(emuDBhandle,query,timeRefSegmentLevel, filteredTablesSuffix, calcTimes, verbose)
         drop_allTmpTablesDBI(emuDBhandle)
         return(emuRsegs)
       }else if(resultType=='emusegs'){
@@ -1370,7 +1356,7 @@ query <- function(emuDBhandle, query, sessionPattern = '.*', bundlePattern = '.*
           # TODO 
           stop("Parameter timeRefSegmentLevel not yet supported for resultType 'emusegs'. Please use resultType 'emuRsegs' (default).")
         }
-        return(query_databaseWithEqlEmusegs(emuDBhandle, query, timeRefSegmentLevel, filteredTablesSuffix, calcTimes))
+        return(query_databaseWithEqlEmusegs(emuDBhandle, query, timeRefSegmentLevel, filteredTablesSuffix, calcTimes, verbose))
       }else{
         stop("Unknown result type: '",resultType,"'. Supported result types: 'emuRsegs', emusegs'")
       }
