@@ -458,9 +458,9 @@ serve <- function(emuDBhandle, sessionPattern='.*',bundlePattern='.*', seglist =
   }
   # store handle global for recovery after crash otr terminated R session
   setServerHandle(sh)
-  cat("Navigate your browser to the EMU-webApp URL: http://ips-lmu.github.io/EMU-webApp/\n")
+  cat("Navigate your browser to the EMU-webApp URL: http://ips-lmu.github.io/EMU-webApp/ (should happen automatically)\n")
   cat("Server connection URL: ws://localhost:",port,"\n",sep='')
-  cat("To stop the server press EMU-webApp 'clear' button or reload the page in your browser.\n")
+  cat("To stop the server press 'clear' button in the EMU-webApp or close/reload the webApp in your browser.\n")
   emuRserverRunning=TRUE
   if(length(autoOpenURL) != 0 && autoOpenURL != ""){
     # open browser with EMU-webApp
